/**
 *  @filename: DateUtils.java
 *  @create date: 2003-04-02
 *  @author: Blue Octave, Inc. - Walter Kaselow
 *
 *  @version 1.0.0
 *  @revision date:
 *
 */

package gov.grants.utility;

// Sun
import java.util.Date;
import java.util.GregorianCalendar;
import java.text.SimpleDateFormat;
import java.text.ParsePosition;


/**
 *  This class contains date utility methods 
 */
public final class DateUtils {

    private DateUtils() {}

    /************************
     *  :: UTILITY METHODS ::
     ************************/

    /**
     *  Returns a static Date instance
     *
     *  @param  dateStr - String     date string
     *  @param  dateFormatStr - String   date format
     */
    public static Date stringToDate( String dateStr, String dateFormatStr ) {
        if ( dateStr == null || dateStr.trim().length() == 0 || 
             dateFormatStr == null || dateFormatStr.trim().length() == 0 ) { return null; }
        
        SimpleDateFormat sdf = new SimpleDateFormat( dateFormatStr );
        return sdf.parse( dateStr, new ParsePosition( 0 ) );
        
    }// end stringToDate()
    
    /**
     *  Returns a static String representation of the given date and date format
     *
     *  @param  date - Date
     *  @param  dateFormatStr - String   date format
     */
    public static String dateToString( Date date, String dateFormatStr ) {
        if ( date == null || dateFormatStr == null || dateFormatStr.trim().length() == 0 ) { return null; }
        
        SimpleDateFormat sdf = new SimpleDateFormat( dateFormatStr );
        return sdf.format( date );
        
    }// end dateToString()
    
    /**
     *  Compares two date strings by the given format string and returns a boolean
     *  based upon begin date string is before end date string
     *
     *  @param  beginDateStr - String
     *  @param  endDateStr - String
     *  @param  dateFormatStr - String
     *  @return boolean
     */
    public static boolean isBefore( String beginDateStr, String endDateStr, String dateFormatStr ) {
        Date beginDate = stringToDate( beginDateStr, dateFormatStr );
        Date endDate = stringToDate( endDateStr, dateFormatStr );
        if ( beginDate == null || endDate == null ) { return false; }
        
        return isBefore( beginDate, endDate );
        
    }// isBefore()
    
    /**
     *  Compares two java.util.Date objects and returns a boolean
     *  based upon beginDate is before endDate
     *
     *  @param  beginDate - java.util.Date
     *  @param  endDate - java.util.Date
     *  @return boolean
     */
    public static boolean isBefore( Date beginDate, Date endDate ) {
        if ( beginDate == null || endDate == null ) { return false; }
        GregorianCalendar calBegin = new GregorianCalendar();
        calBegin.setTime( beginDate );
	    GregorianCalendar calEnd = new GregorianCalendar();
        calEnd.setTime( endDate );
        
        return calBegin.before( calEnd );
        
    }// isBefore()
	
    /**
     *  Returns a java.util.Calendar in XSD Date format
     *  @param  date - java.util.Calendar
     *  @return String representing XSD Date format
     */
	public static String getDateAsXSDDate(java.util.Calendar date ) {
		
		if ( date == null) { return "xxxx-xx-xx"; }
		String year = java.lang.Integer.toString( date.get(java.util.Calendar.YEAR) );
		String month = ( date.get(java.util.Calendar.MONTH) + 1) < 10 
		? "0" + java.lang.Integer.toString( date.get(java.util.Calendar.MONTH) + 1 ) 
		: java.lang.Integer.toString( date.get(java.util.Calendar.MONTH) + 1 );
		String day = ( date.get(java.util.Calendar.DAY_OF_MONTH) ) < 10 
		? "0" + java.lang.Integer.toString( date.get(java.util.Calendar.DAY_OF_MONTH) ) 
		: java.lang.Integer.toString( date.get(java.util.Calendar.DAY_OF_MONTH) );
		
		return year + "-" + month + "-" + day; 
	}
    
}// DateUtils

