/*
 *  DaoMediator.java
 *
 *  @author :: Dan Dumitru, David Xia ::
 *  Created on 2003-07-14
 *	
 *	This class acts as a Mediator between the Data Access Objects 
 *  found in the DB layer and the rest of the application.  
 * 
 *	The createXXX() methods take JAXB objects as parameters. These  
 *  objects represent unmarshaled Application XML component (header,  
 *  core sf424, sf424a-d, and footer) objects.  The JAXB objects are
 *  converted to value objects that are then passed as parameters
 *  to the Data Access Objects (DAO's) that interface with the MySQL
 *  relational DB tables via SQL.
 *
 *  The loadXXX() methods accept the Grant.gov tracking number key as a
 *  parameter.  This key is used to instantiate a 'shell' value object
 *  that is then passed to the load() method of a given DAO.  The DAO,
 *  in turn, retrieves the respective row(s) from the DB using the 
 *  supplied key, and populates the value object which is then returned
 *  to the caller.
 *  
 */

package gov.grants.xmlToDB.utility;

// sun
import java.io.*;
import java.sql.*;
import java.util.ArrayList;
import java.util.List;
import java.lang.Integer;
import java.util.ListIterator;

// reference implementation
import gov.grants.utility.DBUtils;

import gov.grants.system.header.*;
import gov.grants.sf424.*;
import gov.grants.sf424a.*;
import gov.grants.sf424b.*;
import gov.grants.sf424c.*;
import gov.grants.sf424d.*;
import gov.grants.system.footer.*;

import gov.grants.xmlToDB.dao.*;
import gov.grants.xmlToDB.valueobject.*;

public class DaoMediator {

    private DaoMediator() {}

	 
    /*****************
     *  PUBLIC METHODS
     ****************/
	 
	 public static void createHeader( gov.grants.system.header.GrantSubmissionHeader header, String grants_govTrackingNumber )
	 throws Exception {
		 if ( header == null ) {
			 return;
		 }
		 
		 Sf424header valueobject = new Sf424header();
		 
		 valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 valueobject.setAgencyName( header.getAgencyName() );
		 valueobject.setCFDANumber( header.getCFDANumber() );
		 valueobject.setActivityTitle( header.getActivityTitle() );
		 valueobject.setOpportunityID( header.getOpportunityID() );
		 valueobject.setOpportunityTitle( header.getOpportunityTitle() );
		 valueobject.setCompetitionID( header.getCompetitionID() );
		 
		 valueobject.setOpeningDate(  new java.sql.Date( header.getOpeningDate().getTime().getTime() )  );
		 valueobject.setClosingDate(  new java.sql.Date( header.getClosingDate().getTime().getTime() )  );
		 valueobject.setSubmissionTitle( header.getSubmissionTitle() );
//		 valueobject.setHashValue( header.getHashValue().getValue );
		 valueobject.setHashAlgorithm( header.getHashValue().getHashAlgorithm() );
		 valueobject.setSchemaVersion( header.getSchemaVersion() );
		 
		 System.out.println( "Sf424header = " + valueobject.toString() );
		 
		 Sf424headerDao.create( DBUtils.getConnection(), valueobject);
		 
	 }
	 
	 public static void createCover( gov.grants.sf424.AwardingAgencyGrantApplication sf424GrantApplication, String grants_govTrackingNumber )
	 throws Exception {
		 if ( sf424GrantApplication == null ) {
			 return;
		 }
		 
		 Sf424Cover valueobject = new Sf424Cover();
		 
		valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber  );
		
		valueobject.setAuthorizedRepresentativeSignature( sf424GrantApplication.getAuthorizedRepresentativeSignature() );
		if ( sf424GrantApplication.getSignedDate() != null ) {
			valueobject.setSignedDate( new java.sql.Date( sf424GrantApplication.getSignedDate().getTime().getTime() ) );
		}
		valueobject.setAgencySchemaVersion( sf424GrantApplication.getAgencySchemaVersion() );
		valueobject.setFromVersionIdentifier( sf424GrantApplication.getFormVersionIdentifier() );
		valueobject.setSubmissionTypeCode( sf424GrantApplication.getSubmissionTypeCode() );
		if ( sf424GrantApplication.getSubmittedDate() != null ) {
			valueobject.setSubmittedDate( new java.sql.Date( sf424GrantApplication.getSubmittedDate().getTime().getTime() ) );
		}
		valueobject.setApplicationTypeCode( sf424GrantApplication.getApplicationTypeCode()  );
		valueobject.setAgencyName( sf424GrantApplication.getAgencyName() );
		if ( sf424GrantApplication.getAgencyReceivedDate() != null ) {
			valueobject.setAgencyReceivedDate( new java.sql.Date( sf424GrantApplication.getAgencyReceivedDate().getTime().getTime() ) );
		}
		if ( sf424GrantApplication.getStateReceivedDate() != null ) {
			valueobject.setStateReceivedDate( new java.sql.Date( sf424GrantApplication.getStateReceivedDate().getTime().getTime() )  );
		}
		valueobject.setStateID( sf424GrantApplication.getStateID() );
		valueobject.setFederalID( sf424GrantApplication.getFederalID() );
		valueobject.setCFDANumber( sf424GrantApplication.getCFDANumber() );
		valueobject.setActivityTitle( sf424GrantApplication.getActivityTitle() );
		if ( sf424GrantApplication.getAssurance() != null ){
			valueobject.setAssurance( sf424GrantApplication.getAssurance().equalsIgnoreCase( "Y" ) ? 1 : 0 );
		}
		valueobject.setStateReviewCode( sf424GrantApplication.getStateReviewCode()  );
		if ( sf424GrantApplication.getStateReviewDate() != null ) {
			valueobject.setStateReviewDate( new java.sql.Date( sf424GrantApplication.getStateReviewDate().getTime().getTime() )  );
		}
		
		gov.grants.sf424.RevisionType revision =  sf424GrantApplication.getRevision();
		if ( revision != null ) {
			valueobject.setRevisionCode1( revision.getRevisionCode1() );
			valueobject.setRevisionCode2( revision.getRevisionCode2() );
			valueobject.setRevisionOtherExplanation( revision.getRevisionOtherExplanation() );
		}

		gov.grants.sf424.SubmittingOrganizationType submittingOrganization = sf424GrantApplication.getSubmittingOrganization();
		if ( submittingOrganization != null ) {		
			
			gov.grants.sf424.OrganizationIdentifyingInformationType orgIdInfo = submittingOrganization.getOrganizationIdentifyingInformation();
			if ( orgIdInfo != null ) {
				valueobject.setApplicantTypeCodeOtherExplanation( orgIdInfo.getApplicantTypeCodeOtherExplanation() );
				valueobject.setApplicantTypeCode( orgIdInfo.getApplicantTypeCode() );
				valueobject.setApplicantID( orgIdInfo.getApplicantID() );
				
				gov.grants.sf424.OrganizationType organization = orgIdInfo.getOrganization();
				if ( organization != null ) {
					valueobject.setDUNSID( organization.getDUNSID() );
					valueobject.setDepartmentName( organization.getDepartmentName() );
					valueobject.setDivisionName( organization.getDivisionName()  );
					valueobject.setEmployerID( organization.getEmployerID() );
					valueobject.setOrganizationName( organization.getOrganizationName() );
				}
			}
			
			gov.grants.sf424.AddressType address = submittingOrganization.getAddress();
			if ( address != null ) {
				valueobject.setStreet( address.getStreet() );
				valueobject.setCity( address.getCity()  );
				valueobject.setCounty( address.getCounty() );
				valueobject.setStateCode( address.getStateCode() );
				valueobject.setZipCode( address.getZipCode() );
				valueobject.setCountry( address.getCountry() );
			}
			
			if ( submittingOrganization.getDelinquentFederalDebtIndicator() != null ){
				valueobject.setDelinquentFederalDebtIndicator( submittingOrganization.getDelinquentFederalDebtIndicator().equalsIgnoreCase( "Y" ) ? 1 : 0 );
			}
			valueobject.setDelinquentFederalDebtExplanation( submittingOrganization.getDelinquentFederalDebtExplanation() );
			valueobject.setOrganizationCongressionalDistrict( submittingOrganization.getCongressionalDistrict() );
		}
		
		gov.grants.sf424.ProjectType project = sf424GrantApplication.getProject();
		if ( project != null ) {
			valueobject.setProjectTitle( project.getProjectTitle() );
			valueobject.setLocation( project.getLocation()  );
			if ( project.getProposedStartDate() != null ) {
				valueobject.setProposedStartDate( new java.sql.Date( project.getProposedStartDate().getTime().getTime() )  );
			}
			if ( project.getProposedEndDate() != null ) {
				valueobject.setProposedEndDate( new java.sql.Date( project.getProposedEndDate().getTime().getTime() )  );
			}
			valueobject.setProjectCongressionalDistrict( project.getCongressionalDistrict() );
		}
		
		gov.grants.sf424.BudgetType budget = sf424GrantApplication.getBudget();
		if ( budget != null ) {
			valueobject.setFederalEstimatedAmount( budget.getFederalEstimatedAmount() );
			valueobject.setApplicantEstimatedAmount( budget.getApplicantEstimatedAmount() );
			valueobject.setStateEstimatedAmount( budget.getStateEstimatedAmount()  );
			valueobject.setLocalEstimatedAmount( budget.getLocalEstimatedAmount() );
			valueobject.setOtherEstimatedAmount( budget.getOtherEstimatedAmount() );
			valueobject.setProgramIncomeEstimatedAmount( budget.getProgramIncomeEstimatedAmount() );
			valueobject.setTotalEstimatedAmount( budget.getTotalEstimatedAmount()  );
		}

		gov.grants.sf424.IndividualType individual = sf424GrantApplication.getIndividual();
		if ( individual != null ) {
			gov.grants.sf424.ContactType contact = individual.getContact();
			if ( contact != null ) {
				valueobject.setApplicantNamePrefix( contact.getNamePrefix()  );
				valueobject.setApplicantGivenName1( contact.getGivenName1() );
				valueobject.setApplicantGivenName2( contact.getGivenName2() );
				valueobject.setApplicantFamilyName( contact.getFamilyName() );
				valueobject.setApplicantNameSuffix( contact.getNameSuffix() );
				valueobject.setApplicantTelephoneNumber( contact.getTelephoneNumber() );
				valueobject.setApplicantFaxNumber( contact.getFaxNumber() );
				valueobject.setApplicantEmail( contact.getElectronicMailAddress()  );
			}
			
			gov.grants.sf424.AuthorizedRepresentativeType representative = individual.getAuthorizedRepresentative();
			if ( representative != null ) {
				valueobject.setAORNamePrefix( representative.getNamePrefix() );
				valueobject.setAORGivenName1( representative.getGivenName1() );
				valueobject.setAORGivenName2( representative.getGivenName2() );
				valueobject.setAORFamilyName( representative.getFamilyName() );
				valueobject.setAORNameSuffix( representative.getNameSuffix() );
				valueobject.setRepresentativeTitle( representative.getRepresentativeTitle()  );
				valueobject.setAORTelephoneNumber( representative.getTelephoneNumber()  );
			}
		}
		
//        valueobject.setAgencyTrackingNumber( sf424GrantApplication.get???);
		 
		 System.out.println( "sf424GrantApplication = " + valueobject.toString() );
		 
		 Sf424CoverDao.create( DBUtils.getConnection(), valueobject);
		 
	 }
	 
	 public static void createFooter( gov.grants.system.footer.GrantSubmissionFooter footer, String grants_govTrackingNumber )
	 throws Exception {
		 if ( footer == null ) {
			 return;
		 }
		 
		 Sf424footer valueobject = new Sf424footer();
		 
		 valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 valueobject.setReceivedDateTime( new java.sql.Timestamp( footer.getReceivedDateTime().getTime().getTime() ) );
		 valueobject.setSubmitterName( footer.getSubmitterName() );
//		 valueobject.setHashValue( footer.getHashValue().getValue );
		 valueobject.setHashAlgorithm( footer.getHashValue().getHashAlgorithm() );
		 valueobject.setSchemaVersion( footer.getSchemaVersion() );
		 
		 System.out.println( "Sf424footer = " + valueobject.toString() );
		 
		 Sf424footerDao.create( DBUtils.getConnection(), valueobject);
		 
	 }
	 
	 public static void createSf424bAssurances( gov.grants.sf424b.Assurances sf424bAssurances, String grants_govTrackingNumber )
	 throws Exception {
		 if ( sf424bAssurances == null ) {
			 return;
		 }
		 
		 gov.grants.xmlToDB.valueobject.Sf424b valueobject = new gov.grants.xmlToDB.valueobject.Sf424b();
		 valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 valueobject.setApplicantOrganizationName(sf424bAssurances.getApplicantOrganizationName());
		 valueobject.setFormVersionIdentifier(sf424bAssurances.getFormVersionIdentifier());
		 valueobject.setProgramType(sf424bAssurances.getProgramType());
		 valueobject.setRepresentativeName(sf424bAssurances.getAuthorizedRepresentative().getRepresentativeName());
		 valueobject.setRepresentativeTitle(sf424bAssurances.getAuthorizedRepresentative().getRepresentativeTitle());
		 valueobject.setSubmittedDate( new java.sql.Date( sf424bAssurances.getSubmittedDate().getTime().getTime() )  );
     
		 System.out.println( "Sf424b = " + valueobject.toString() );
		 
		 Sf424bDao.create( DBUtils.getConnection(), valueobject);
		 
	 }
	 

	 public static void createSf424dAssurances( gov.grants.sf424d.Assurances  sf424dAssurances, String grants_govTrackingNumber )
	 throws Exception {
		 if ( sf424dAssurances == null ) {
			 return;
		 }
		 
		 gov.grants.xmlToDB.valueobject.Sf424d valueobject = new gov.grants.xmlToDB.valueobject.Sf424d();
		 valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 valueobject.setApplicantOrganizationName(sf424dAssurances.getApplicantOrganizationName());
		 valueobject.setFormVersionIdentifier(sf424dAssurances.getFormVersionIdentifier());
		 valueobject.setProgramType(sf424dAssurances.getProgramType());
		 valueobject.setRepresentativeName(sf424dAssurances.getAuthorizedRepresentative().getRepresentativeName());
		 valueobject.setRepresentativeTitle(sf424dAssurances.getAuthorizedRepresentative().getRepresentativeTitle());
		 valueobject.setSubmittedDate( new java.sql.Date( sf424dAssurances.getSubmittedDate().getTime().getTime() )  );
	 
		 System.out.println( "Sf424d = " + valueobject.toString() );
		 
		 Sf424dDao.create( DBUtils.getConnection(), valueobject);
		 
	 }
         

	 public static void createSf424cBudgetInformation( gov.grants.sf424c.BudgetInformation sf424cBudgetInformation, String grants_govTrackingNumber )
	 throws Exception {
		 if ( sf424cBudgetInformation == null ) {
			 return;
		 }
		 
		 gov.grants.xmlToDB.valueobject.Sf424c_budgetinfo valueobjectBudgetInfo = new gov.grants.xmlToDB.valueobject.Sf424c_budgetinfo();
		 gov.grants.xmlToDB.valueobject.Sf424c_federalfunding valueobjectFederalFunding = new gov.grants.xmlToDB.valueobject.Sf424c_federalfunding();
		 String formVersionIdentifier = sf424cBudgetInformation.getFormVersionIdentifier();
		 
		 valueobjectFederalFunding.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 valueobjectFederalFunding.setFederalFundingPercentageShareValue(sf424cBudgetInformation.getFederalFundingPercentageShareValue().intValue());
		 valueobjectFederalFunding.setFederalFundingShareValue(sf424cBudgetInformation.getFederalFundingShareValue());
		 valueobjectFederalFunding.setFormVersionIdentifier(formVersionIdentifier);

		 System.out.println( "Sf424c FederalFunding = " + valueobjectFederalFunding.toString() );
		 Sf424c_federalfundingDao.create( DBUtils.getConnection(), valueobjectFederalFunding);
                 
		 gov.grants.sf424c.ProjectCostsType projectCosts = sf424cBudgetInformation.getProjectCosts();
		 if ( projectCosts != null ) {
			 
			 java.util.List costLineItemList = projectCosts.getCostLineItem();
			 System.out.println( "costLineItemList size = " + costLineItemList.size() );
			 if ( costLineItemList != null ) {
				java.util.ListIterator costLineItemIterator = costLineItemList.listIterator();
				gov.grants.sf424c.CostLineItemType costLineItem;
				while ( costLineItemIterator.hasNext() )
				{
					costLineItem = (gov.grants.sf424c.CostLineItemType)(costLineItemIterator.next());
					valueobjectBudgetInfo.setGrants_govTrackingNumber( grants_govTrackingNumber );
					valueobjectBudgetInfo.setFormVersionIdentifier( formVersionIdentifier );
					valueobjectBudgetInfo.setCostClassification(costLineItem.getClassificationID());
					valueobjectBudgetInfo.setBudgetEstimatedCostAmount( costLineItem.getBudgetEstimatedCostAmount() );
					valueobjectBudgetInfo.setBudgetNonAllowableCostAmount( costLineItem.getBudgetNonAllowableCostAmount() );
					valueobjectBudgetInfo.setBudgetTotalAllowableCostAmount( costLineItem.getBudgetTotalAllowableCostAmount() );
					
					System.out.println( "Sf424c BudgetInfo Cost Line Item = " + valueobjectBudgetInfo.toString() );
					Sf424c_budgetinfoDao.create( DBUtils.getConnection(), valueobjectBudgetInfo);
				}
			 }

			// Contingencies
			gov.grants.sf424c.ContingenciesType contingencies = projectCosts.getContingencies();
			if ( contingencies != null ) {

				valueobjectBudgetInfo.setGrants_govTrackingNumber( grants_govTrackingNumber );
				valueobjectBudgetInfo.setFormVersionIdentifier( formVersionIdentifier );
				valueobjectBudgetInfo.setCostClassification( "Contingencies" );
				valueobjectBudgetInfo.setBudgetEstimatedCostAmount(contingencies.getBudgetEstimatedCostAmount());
				valueobjectBudgetInfo.setBudgetNonAllowableCostAmount( contingencies.getBudgetNonAllowableCostAmount());
				valueobjectBudgetInfo.setBudgetTotalAllowableCostAmount( contingencies.getBudgetTotalAllowableCostAmount());
				
				System.out.println( "Sf424c BudgetInfo Contingencies = " + valueobjectBudgetInfo.toString() );
				Sf424c_budgetinfoDao.create( DBUtils.getConnection(), valueobjectBudgetInfo);
			}

			// CostSubtotalBeforeContingencies
			gov.grants.sf424c.CostSubtotalBeforeContingenciesType costSubtotalBeforeContingenciesType = projectCosts.getCostSubtotalBeforeContingencies();
			if ( costSubtotalBeforeContingenciesType != null ) {

				valueobjectBudgetInfo.setGrants_govTrackingNumber( grants_govTrackingNumber );
				valueobjectBudgetInfo.setFormVersionIdentifier( formVersionIdentifier );
				valueobjectBudgetInfo.setCostClassification( "CostSubtotalBeforeContingencies" );
				valueobjectBudgetInfo.setBudgetEstimatedCostAmount( costSubtotalBeforeContingenciesType.getBudgetEstimatedCostAmount());
				valueobjectBudgetInfo.setBudgetNonAllowableCostAmount( costSubtotalBeforeContingenciesType.getBudgetNonAllowableCostAmount() );
				valueobjectBudgetInfo.setBudgetTotalAllowableCostAmount( costSubtotalBeforeContingenciesType.getBudgetTotalAllowableCostAmount());
		
				System.out.println( "Sf424c BudgetInfo CostSubtotalAfterContingencies = " + valueobjectBudgetInfo.toString() );                
				Sf424c_budgetinfoDao.create( DBUtils.getConnection(), valueobjectBudgetInfo);
			}
			
			// CostSubtotalAfterContingencies
			gov.grants.sf424c.CostSubtotalAfterContingenciesType costSubtotalAfterContingenciesType = projectCosts.getCostSubtotalAfterContingencies();
			if ( costSubtotalAfterContingenciesType != null ) {
				
				valueobjectBudgetInfo.setGrants_govTrackingNumber( grants_govTrackingNumber );
				valueobjectBudgetInfo.setFormVersionIdentifier( formVersionIdentifier );
				valueobjectBudgetInfo.setCostClassification( "CostSubtotalAfterContingencies" );
				valueobjectBudgetInfo.setBudgetEstimatedCostAmount( costSubtotalAfterContingenciesType.getBudgetEstimatedCostAmount() );
				valueobjectBudgetInfo.setBudgetNonAllowableCostAmount( costSubtotalAfterContingenciesType.getBudgetNonAllowableCostAmount() );
				valueobjectBudgetInfo.setBudgetTotalAllowableCostAmount( costSubtotalAfterContingenciesType.getBudgetTotalAllowableCostAmount() );
				
				System.out.println( "Sf424c BudgetInfo CostSubtotalAfterContingencies = " + valueobjectBudgetInfo.toString() );                
				Sf424c_budgetinfoDao.create( DBUtils.getConnection(), valueobjectBudgetInfo );
			}
					
	
			// ProgramIncome
			gov.grants.sf424c.ProgramIncomeType programIncomeType = projectCosts.getProgramIncome();
			if ( programIncomeType != null ) {
				valueobjectBudgetInfo.setGrants_govTrackingNumber( grants_govTrackingNumber );
				valueobjectBudgetInfo.setFormVersionIdentifier( formVersionIdentifier );
				valueobjectBudgetInfo.setCostClassification( "CostSubtotalAfterContingencies" );
				valueobjectBudgetInfo.setBudgetEstimatedCostAmount( programIncomeType.getBudgetEstimatedCostAmount());
				valueobjectBudgetInfo.setBudgetNonAllowableCostAmount( programIncomeType.getBudgetNonAllowableCostAmount());
				valueobjectBudgetInfo.setBudgetTotalAllowableCostAmount( programIncomeType.getBudgetTotalAllowableCostAmount());
				
				System.out.println( "Sf424c BudgetInfo ProgramIncome = " + valueobjectBudgetInfo.toString() );
				Sf424c_budgetinfoDao.create( DBUtils.getConnection(), valueobjectBudgetInfo);
			}

			// TotalProjectCosts
			gov.grants.sf424c.TotalProjectCostsType totalProjectCostsType = projectCosts.getTotalProjectCosts();
			if ( totalProjectCostsType != null ) {
				valueobjectBudgetInfo.setGrants_govTrackingNumber( grants_govTrackingNumber );
				valueobjectBudgetInfo.setFormVersionIdentifier( formVersionIdentifier );
				valueobjectBudgetInfo.setCostClassification( "TotalProjectCosts" );
				valueobjectBudgetInfo.setBudgetEstimatedCostAmount( totalProjectCostsType.getBudgetEstimatedCostAmount());
				valueobjectBudgetInfo.setBudgetNonAllowableCostAmount( totalProjectCostsType.getBudgetNonAllowableCostAmount());
				valueobjectBudgetInfo.setBudgetTotalAllowableCostAmount( totalProjectCostsType.getBudgetTotalAllowableCostAmount());
				System.out.println( "Sf424c BudgetInfo TotalProjectCosts = " + valueobjectBudgetInfo.toString() );
				Sf424c_budgetinfoDao.create( DBUtils.getConnection(), valueobjectBudgetInfo);
			}
		
		} // Project Costs
	 }

         
	 public static Sf424header loadHeader( String grants_govTrackingNumber )
	 throws Exception {
		 if ( grants_govTrackingNumber == null ) {
			 throw new Exception( "The grants_govTrackingNumber is required when loading the Header" );
		 }
		 
		 Sf424header valueobject = new Sf424header();
		 valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 
		 Sf424headerDao.load( DBUtils.getConnection(), valueobject );
		 
		 System.out.println( "Loaded Sf424header = " + valueobject.toString() );
		 return valueobject;
		 
	 }
	 
	 public static Sf424Cover loadCover( String grants_govTrackingNumber )
	 throws Exception {
		 if ( grants_govTrackingNumber == null ) {
			 throw new Exception( "The grants_govTrackingNumber is required when loading the sf424 Cover" );
		 }
		 
		 Sf424Cover valueobject = new Sf424Cover();
		 valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 
		 Sf424CoverDao.load( DBUtils.getConnection(), valueobject );
		 
		 System.out.println( "Loaded Sf424Cover = " + valueobject.toString() );
		 return valueobject;
		 
	 }

	 public static Sf424footer loadFooter( String grants_govTrackingNumber )
	 throws Exception {
		 if ( grants_govTrackingNumber == null ) {
			 throw new Exception( "The grants_govTrackingNumber is required when loading the Footer" );
		 }
		 
		 Sf424footer valueobject = new Sf424footer();
		 valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 
		 Sf424footerDao.load( DBUtils.getConnection(), valueobject );
		 
		 System.out.println( "Loaded Sf424Footer = " + valueobject.toString() );
		 return valueobject;
		 
	 }
         
/*
	 public static Sf424b loadSf424b( String grants_govTrackingNumber )
	 throws Exception {
		 if ( grants_g                valueobjectBudgetInfo.setGrants_govTrackingNumber( grants_govTrackingNumber );
                valueobjectBudgetInfo.setFormVersionIdentifier( sf424cBudgetInformation.getFormVersionIdentifier() );
                valueobjectBudgetInfo.setCostClassification( "CostSubtotalAfterContingencies" );
                valueobjectBudgetInfo.setBudgetEstimatedCostAmount( sf424cBudgetInformation.getProjectCosts().getCostSubtotalAfterContingencies().getBudgetEstimatedCostAmount());
                valueobjectBudgetInfo.setBudgetNonAllowableCostAmount( sf424cBudgetInformation.getProjectCosts().getCostSubtotalAfterContingencies().getBudgetNonAllowableCostAmount());
                valueobjectBudgetInfo.setBudgetTotalAllowableCostAmount( sf424cBudgetInformation.getProjectCosts().getCostSubtotalAfterContingencies().getBudgetTotalAllowableCostAmount());                
                Sf424c_budgetinfoDao.create( DBUtils.getConnection(), valueobjectBudgetInfo);ovTrackingNumber == null ) {
			 throw new Exception( "The grants_govTrackingNumber is required when loading the Footer" );
		 }
		 
		 Sf424b valueobject = new Sf424b();
		 valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 
		 Sf424bDao.load( DBUtils.getConnection(), valueobject );
		 
		 System.out.println( "Sf424b = " + valueobject.toString() );
		 return valueobject;
		 
	 }         

         public static Sf424d loadSf424d( String grants_govTrackingNumber )
	 throws Exception {
		 if ( grants_govTrackingNumber == null ) {
			 throw new Exception( "The grants_govTrackingNumber is required when loading the Footer" );
		 }
		 
		 Sf424d valueobject = new Sf424d();
		 valueobject.setGrants_govTrackingNumber( grants_govTrackingNumber );
		 
		 Sf424dDao.load( DBUtils.getConnection(), valueobject );
		 
		 System.out.println( "Sf424b = " + valueobject.toString() );
		 return valueobject;
		 
	 }   
    */
}// end DaoMediator
